@@ -1,17 +1,17 @@
-<?php /* Smarty version Smarty-3.1.21-dev, created on 2016-12-14 16:22:37
+<?php /* Smarty version Smarty-3.1.21-dev, created on 2017-04-28 08:25:02
          compiled from "ls:view.tpl" */ ?>
-<?php /*%%SmartyHeaderCode:372768082585171cdbf3bc4-06762496%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
+<?php /*%%SmartyHeaderCode:4558762805902fc5e4acad4-18605049%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
 $_valid = $_smarty_tpl->decodeProperties(array (
   'file_dependency' => 
   array (
     'bba6ee792d4eef9885de9f88ca7e9ab08b301591' => 
     array (
       0 => 'ls:view.tpl',
-      1 => 1472212472,
+      1 => 1485342206,
       2 => 'ls',
     ),
   ),
-  'nocache_hash' => '372768082585171cdbf3bc4-06762496',
+  'nocache_hash' => '4558762805902fc5e4acad4-18605049',
   'function' => 
   array (
   ),
@@ -24,9 +24,9 @@ $_valid = $_smarty_tpl->decodeProperties(array (
   ),
   'has_nocache_code' => false,
   'version' => 'Smarty-3.1.21-dev',
-  'unifunc' => 'content_585171cdc0e908_48159878',
+  'unifunc' => 'content_5902fc5e4d5398_78899024',
 ),false); /*/%%SmartyHeaderCode%%*/?>
-<?php if ($_valid && !is_callable('content_585171cdc0e908_48159878')) {function content_585171cdc0e908_48159878($_smarty_tpl) {?><?php echo $_smarty_tpl->getSubTemplate ('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>
+<?php if ($_valid && !is_callable('content_5902fc5e4d5398_78899024')) {function content_5902fc5e4d5398_78899024($_smarty_tpl) {?><?php echo $_smarty_tpl->getSubTemplate ('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>
 
     <?php if ($_smarty_tpl->tpl_vars['pagetitle']->value!='') {?><h1 id='LSview_title'><?php echo $_smarty_tpl->tpl_vars['pagetitle']->value;?>
 </h1><?php }?>
@@ -39,10 +39,15 @@ $_smarty_tpl->tpl_vars['item']->_loop = true;
 ?>
         <?php if (is_array($_smarty_tpl->tpl_vars['item']->value)) {?>
         <li class='LSview-actions'><a href="<?php echo $_smarty_tpl->tpl_vars['item']->value['url'];?>
-" class="LSview-actions<?php if ($_smarty_tpl->tpl_vars['item']->value['class']) {?> <?php echo $_smarty_tpl->tpl_vars['item']->value['class'];
-}?>" ><img src="<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
-" alt="<?php echo $_smarty_tpl->tpl_vars['item']->value['label'];?>
-" title="<?php echo $_smarty_tpl->tpl_vars['item']->value['label'];?>
+" class="LSview-actions<?php if ($_smarty_tpl->tpl_vars['item']->value['class']) {?> <?php echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['class']);
+}
+if ($_smarty_tpl->tpl_vars['item']->value['helpInfo']||($_smarty_tpl->tpl_vars['item']->value['hideLabel']&&$_smarty_tpl->tpl_vars['item']->value['label'])) {?> LStips<?php }?>" <?php if ($_smarty_tpl->tpl_vars['item']->value['helpInfo']||($_smarty_tpl->tpl_vars['item']->value['hideLabel']&&$_smarty_tpl->tpl_vars['item']->value['label'])) {?>title="<?php if ($_smarty_tpl->tpl_vars['item']->value['helpInfo']) {
+echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['helpInfo']);
+} else {
+echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['label']);
+}?>"<?php }?>><img src="<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
+" alt="<?php echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['label']);?>
+" title="<?php echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['label']);?>
 " /><?php if (!isset($_smarty_tpl->tpl_vars['item']->value['hideLabel'])||!$_smarty_tpl->tpl_vars['item']->value['hideLabel']) {?> <?php echo $_smarty_tpl->tpl_vars['item']->value['label'];
 }?></a></li>
         <?php }?>
