@@ -1,17 +1,17 @@
-<?php /* Smarty version Smarty-3.1.21-dev, created on 2016-12-14 16:22:37
+<?php /* Smarty version Smarty-3.1.21-dev, created on 2017-04-28 08:25:02
          compiled from "ls:top.tpl" */ ?>
-<?php /*%%SmartyHeaderCode:1311245299585171cdc10155-69753689%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
+<?php /*%%SmartyHeaderCode:13027053855902fc5e4d6ed4-37239127%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
 $_valid = $_smarty_tpl->decodeProperties(array (
   'file_dependency' => 
   array (
     'f42923f474b713ac9da912d26a6790568d7df7dd' => 
     array (
       0 => 'ls:top.tpl',
-      1 => 1472212678,
+      1 => 1490276202,
       2 => 'ls',
     ),
   ),
-  'nocache_hash' => '1311245299585171cdc10155-69753689',
+  'nocache_hash' => '13027053855902fc5e4d6ed4-37239127',
   'function' => 
   array (
   ),
@@ -41,9 +41,9 @@ $_valid = $_smarty_tpl->decodeProperties(array (
   ),
   'has_nocache_code' => false,
   'version' => 'Smarty-3.1.21-dev',
-  'unifunc' => 'content_585171cdc35205_62573608',
+  'unifunc' => 'content_5902fc5e4fec39_76906166',
 ),false); /*/%%SmartyHeaderCode%%*/?>
-<?php if ($_valid && !is_callable('content_585171cdc35205_62573608')) {function content_585171cdc35205_62573608($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
+<?php if ($_valid && !is_callable('content_5902fc5e4fec39_76906166')) {function content_5902fc5e4fec39_76906166($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
 ?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
  "http://www.w3.org/TR/html4/loose.dtd">
 <html>
@@ -135,8 +135,12 @@ $_smarty_tpl->tpl_vars['lang']->_loop = true;
     <?php if ($_smarty_tpl->tpl_vars['displaySelfAccess']->value) {
 echo $_smarty_tpl->tpl_vars['connected_as']->value;?>
  <span id='user_name'><?php echo $_smarty_tpl->tpl_vars['LSsession_username']->value;?>
-</span><?php }
-if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='index.php?LSsession_logout'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logout'),$_smarty_tpl);?>
+</span><?php }?>
+    <a href='index.php?LSsession_refresh=1'><img src='<?php echo LStemplate_smarty_img(array('name'=>'refresh'),$_smarty_tpl);?>
+' alt="<?php echo LStemplate_smarty_tr(array('msg'=>"Refresh my access rights"),$_smarty_tpl);?>
+" title="<?php echo LStemplate_smarty_tr(array('msg'=>"Refresh my access rights"),$_smarty_tpl);?>
+" /></a>
+    <?php if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='index.php?LSsession_logout'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logout'),$_smarty_tpl);?>
 ' alt='Logout' title='Logout' /></a><?php }?>
     </td>
   </tr>
